@@ -10,7 +10,7 @@ x3 <- rnorm(1000)
 x4 <- rnorm(1000)
 x5 <- rnorm(1000)
 x6 <- rnorm(1000)
-mu    <- exp(1.5 + x1^2 +0.5 * x2 - 3 * sin(x3) -1 * x4)
+mu    <- exp(1.5 + 0.3 * x1^2 + 0.5 * x2 - 3 * sin(x3) -1 * x4)
 sigma <- exp(-0.2 * x4 +0.2 * x5 +0.4 * x6)
 y <- numeric(1000)
 for( i in 1:1000)
